@@ -5,11 +5,11 @@
  */
 
 //! [code]
-#include <stdlib.h>
 #include <stdio.h>
+#include <stdlib.h>
 
-#include "util_libc.h"
-#include "util_panic.h"
+#include "lib/util_libc.h"
+#include "lib/util_panic.h"
 
 /*
  * Demonstrate that out of memory is automatically handled via panic()
@@ -18,7 +18,15 @@ int main(void)
 {
 	unsigned long ulong_max = (unsigned long)-1;
 	void *ptr;
-	char *zeroes;
+	char *zeroes, *str;
+
+	/* Use util_strcat_realloc() for string concatenation */
+	fprintf(stderr, "Try to concatenate \"Hello\",  \", \" and \"world!\": ");
+	str = util_strdup("Hello");
+	str = util_strcat_realloc(str, ", ");
+	str = util_strcat_realloc(str, "world!");
+	fprintf(stderr, "result = \"%s\"\n", str);
+	free(str);
 
 	/* One byte allocation should work */
 	fprintf(stderr, "Try to allocate 1 byte: ");
