@@ -2,7 +2,7 @@
 #
 # dbginfo.sh - Tool to collect runtime, configuration, and trace information
 #
-# Copyright IBM Corp. 2002, 2016
+# Copyright IBM Corp. 2002, 2017
 #
 
 # Switching to neutral locale
@@ -18,7 +18,7 @@ readonly SCRIPTNAME="${0##*/}"
 print_version() {
     cat <<EOF
 ${SCRIPTNAME}: Debug information script version %S390_TOOLS_VERSION%
-Copyright IBM Corp. 2002, 2016
+Copyright IBM Corp. 2002, 2017
 EOF
 }
 
@@ -115,27 +115,26 @@ fi
 ########################################
 # Global used variables
 #
-
 # The base working directory
 readonly WORKDIR_BASE="$(echo "${paramWORKDIR_BASE}" | sed -e 's#/$##')/"
 
 # The terminal
-readonly TERMINAL=$(tty 2>/dev/null)
+readonly TERMINAL="$(tty 2>/dev/null)"
 
 # The hostname of the system
-readonly SYSTEMHOSTNAME=$(hostname -s 2>/dev/null)
+readonly SYSTEMHOSTNAME="$(hostname -s 2>/dev/null)"
 
 # The kernel release version as delivered from uname -r
-readonly KERNEL_RELEASE_VERSION=$(uname -r 2>/dev/null)
+readonly KERNEL_RELEASE_VERSION="$(uname -r 2>/dev/null)"
 
 # The processor ID for the first processor
-readonly PROCESSORID=$(grep -E ".*processor 0:.*" /proc/cpuinfo | sed 's/.*identification[[:space:]]*\=[[:space:]]*\([[:alnum:]]*\).*/\1/g')
-
+readonly PROCESSORID="$(grep -E ".*processor 0:.*" /proc/cpuinfo | \
+                      sed 's/.*identification[[:space:]]*\=[[:space:]]*\([[:alnum:]]*\).*/\1/g')"
 # The processor version for the first processor
-readonly PROCESSORVERSION=$(grep -E ".*processor 0:.*" /proc/cpuinfo | sed 's/.*version[[:space:]]*\=[[:space:]]*\([[:alnum:]]*\).*/\1/g')
-
+readonly PROCESSORVERSION="$(grep -E ".*processor 0:.*" /proc/cpuinfo | \
+                      sed 's/.*version[[:space:]]*\=[[:space:]]*\([[:alnum:]]*\).*/\1/g')"
 # The current date
-readonly DATETIME=$(date +%Y-%m-%d-%H-%M-%S 2>/dev/null)
+readonly DATETIME="$(date +%Y-%m-%d-%H-%M-%S 2>/dev/null)"
 
 # The current working directory for the actual script execution
 if test -z "${PROCESSORID}"; then
@@ -177,11 +176,14 @@ readonly OUTPUT_FILE_OVS="${WORKPATH}openvswitch"
 # File that includes the KVM domain xml file
 readonly OUTPUT_FILE_XML="${WORKPATH}domain_xml"
 
+# File that includes the docker inspect output
+readonly OUTPUT_FILE_DOCKER="${WORKPATH}docker_inspect.out"
+
 # Mount point of the debug file system
 readonly MOUNT_POINT_DEBUGFS="/sys/kernel/debug"
 
 # The amount of steps running the whole collections
-readonly COLLECTION_COUNT=10
+readonly COLLECTION_COUNT=11
 
 # The kernel version (e.g. '2' from 2.6.32 or '3' from 3.2.1)
 readonly KERNEL_VERSION=$(uname -r 2>/dev/null | cut -d'.' -f1)
@@ -244,6 +246,8 @@ PROCFILES="\
   /proc/qeth\
   /proc/qeth_perf\
   /proc/qeth_ipa_takeover\
+  /proc/sched_debug\
+  /proc/schedstat\
   /proc/service_levels\
   /proc/slabinfo\
   /proc/stat\
@@ -302,6 +306,8 @@ LOGFILES="\
   /var/log/yum.log\
   /var/log/openvswitch/ovs-vswitchd.log\
   /var/log/openvswitch/ovsdb-server.log\
+  /var/run/docker/libcontainerd/containerd/events.log\
+  /run/containerd/events.log\
   "
 
 ########################################
@@ -344,6 +350,7 @@ CONFIGFILES="\
   /etc/resolv.*\
   /etc/rsyslog.d\
   /etc/ssl/openssl.conf\
+  /etc/ssl/openssl.cnf\
   /etc/sysconfig\
   /etc/sysctl.d\
   /etc/syslog*\
@@ -352,6 +359,10 @@ CONFIGFILES="\
   /etc/xinet.d\
   /etc/*release\
   $(find /lib/modules -name modules.dep 2>/dev/null)\
+  /etc/docker\
+  /lib/systemd/system/docker.service\
+  /usr/lib/systemd/system/docker.service\
+  /etc/apparmor.d\
   "
 
 ########################################
@@ -426,18 +437,27 @@ CMDS="uname -a\
   :lsof\
   :mount\
   :df -h\
+  :df -i\
   :pvpath -qa\
   :find /boot -print0 | sort -z | xargs -0 -n 10 ls -ld\
   :find /dev -print0 | sort -z | xargs -0 -n 10 ls -ld\
   :java -version\
   :cat /root/.bash_history\
   :env\
-  :journalctl --all --no-pager --since=$(date -d '5 day ago' +%Y-%m-%d) --until=now --lines=50000 > ${OUTPUT_FILE_JOURNALCTL}\
+  :journalctl --all --no-pager --since=$(date -d '5 day ago' +%Y-%m-%d) --until=now --lines=50000 \
+   > '${OUTPUT_FILE_JOURNALCTL}'\
   :openssl engine\
   :systemd-delta\
   :systemctl --all --no-pager show\
   :systemctl --all --no-pager list-units\
   :systemctl --all --no-pager list-unit-files\
+  :docker info\
+  :docker images\
+  :docker network ls\
+  :docker ps -a\
+  :docker version\
+  :docker stats --no-stream\
+  :systemctl status docker.service\
   "
 
 ########################################
@@ -770,6 +790,36 @@ collect_domain_xml() {
     pr_log_stdout " "
 }
 
+########################################
+collect_docker() {
+    local item_list
+    local item
+
+    # call docker inspect for all containers
+    item_list=$(docker ps -qa)
+    if test -n "${item_list}"; then
+        pr_syslog_stdout "10a of ${COLLECTION_COUNT}: Collecting docker container output"
+        for item in ${item_list}; do
+            call_run_command "docker inspect ${item}" "${OUTPUT_FILE_DOCKER}"
+        done
+    else
+        pr_syslog_stdout "10a of ${COLLECTION_COUNT}: Collecting docker container output skipped"
+    fi
+
+    # call docker inspect for all networks
+    item_list=$(docker network ls -q)
+    if test -n "${item_list}"; then
+        pr_syslog_stdout "10b of ${COLLECTION_COUNT}: Collecting docker network output"
+        for item in ${item_list}; do
+            call_run_command "docker network inspect ${item}" "${OUTPUT_FILE_DOCKER}"
+        done
+    else
+        pr_syslog_stdout "10b of ${COLLECTION_COUNT}: Collecting docker network output skipped"
+    fi
+
+    pr_log_stdout " "
+}
+
 ########################################
 post_processing() {
     local file_mtime
@@ -777,7 +827,7 @@ post_processing() {
     local tmp_file
     local file_name
 
-    pr_syslog_stdout "10 of ${COLLECTION_COUNT}: Postprocessing"
+    pr_syslog_stdout "11 of ${COLLECTION_COUNT}: Postprocessing"
 
     find "${WORKPATH}etc/libvirt/qemu/" -maxdepth 1 -name "*.xml" 2>/dev/null | while IFS= read -r file_name; do
 	file_mtime_epoche=$(stat --format=%Y "${file_name}")
@@ -1060,6 +1110,8 @@ collect_ovs
 
 collect_domain_xml
 
+collect_docker
+
 post_processing
 
 create_package
