@@ -24,15 +24,17 @@
 #include <iconv.h>
 #include <sys/types.h>
 #include <dirent.h>
+#include <sys/sysmacros.h>
 #include <sys/ioctl.h>
-#include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/file.h>
 #include <ctype.h>
 #include <linux/types.h>
-#include "zt_common.h"
+
+#include "lib/vmdump.h"
+#include "lib/zt_common.h"
+
 #include "vmur.h"
-#include "vmdump.h"
 
 /* Program name */
 static char *prog_name;
