@@ -4,8 +4,6 @@
  * Author(s): Peter Oberparleiter <oberpar@linux.vnet.ibm.com>
  */
 
-#include "misc.h"
-
 #include <ctype.h>
 #include <dirent.h>
 #include <errno.h>
@@ -13,8 +11,8 @@
 #include <limits.h>
 #include <signal.h>
 #include <stdarg.h>
-#include <stdio.h>
 #include <stdint.h>
+#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <strings.h>
@@ -28,8 +26,8 @@
 #include "dasd.h"
 #include "device.h"
 #include "devtype.h"
+#include "misc.h"
 #include "path.h"
-#include "util.h"
 
 #define DRYRUN_HEADER_BEGIN	((char) 0x01)
 #define DRYRUN_HEADER_END	((char) 0x02)
@@ -527,24 +525,23 @@ bool misc_read_dir(const char *path, struct util_list *list,
 		   bool (*filter)(const char *, void *), void *data)
 {
 	DIR *dir;
-	struct dirent de;
-	struct dirent *de_ptr;
+	struct dirent *de;
 
 	debug("Reading contents of directory %s\n", path);
 	dir = opendir(path);
 	if (!dir)
 		return false;
 
-	while (!readdir_r(dir, &de, &de_ptr) && de_ptr) {
-		if (de.d_name[0] == '.') {
-			if (de.d_name[1] == 0)
+	while ((de = readdir(dir))) {
+		if (de->d_name[0] == '.') {
+			if (de->d_name[1] == 0)
 				continue;
-			if (de.d_name[1] == '.' && de.d_name[2] == 0)
+			if (de->d_name[1] == '.' && de->d_name[2] == 0)
 				continue;
 		}
-		if (filter && !filter(de.d_name, data))
+		if (filter && !filter(de->d_name, data))
 			continue;
-		strlist_add(list, de.d_name);
+		strlist_add(list, de->d_name);
 	}
 
 	closedir(dir);
